@@ -6,6 +6,8 @@ from zygoat.components import Component
 from zygoat.config import yaml
 from . import resources
 
+from .cache import cache
+
 log = logging.getLogger()
 file_name = "docker-compose.yml"
 
@@ -47,4 +49,4 @@ class DockerCompose(Component):
         return Projects.BACKEND in services and "db" in services
 
 
-docker_compose = DockerCompose()
+docker_compose = DockerCompose(sub_components=[cache])
